/****************************************************************************
** Meta object code from reading C++ file 'kquickconfigmodule.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kcmutils-6.28.0/src/quick/kquickconfigmodule.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kquickconfigmodule.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18KQuickConfigModuleE_t {};
} // unnamed namespace

template <> constexpr inline auto KQuickConfigModule::qt_create_metaobjectdata<qt_meta_tag_ZN18KQuickConfigModuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KQuickConfigModule",
        "QML.Element",
        "ConfigModule",
        "QML.Attached",
        "pagePushed",
        "",
        "QQuickItem*",
        "page",
        "pageRemoved",
        "columnWidthChanged",
        "width",
        "currentIndexChanged",
        "index",
        "depthChanged",
        "mainUiReady",
        "push",
        "fileName",
        "QVariantMap",
        "initialProperties",
        "item",
        "pop",
        "takeLast",
        "mainUi",
        "columnWidth",
        "depth",
        "currentIndex"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pagePushed'
        QtMocHelpers::SignalData<void(QQuickItem *)>(4, 5, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'pageRemoved'
        QtMocHelpers::SignalData<void()>(8, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'columnWidthChanged'
        QtMocHelpers::SignalData<void(int)>(9, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'currentIndexChanged'
        QtMocHelpers::SignalData<void(int)>(11, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'depthChanged'
        QtMocHelpers::SignalData<void(int)>(13, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'mainUiReady'
        QtMocHelpers::SignalData<void()>(14, 5, QMC::AccessPublic, QMetaType::Void),
        // Slot 'push'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(15, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'push'
        QtMocHelpers::SlotData<void(const QString &)>(15, 5, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'push'
        QtMocHelpers::SlotData<void(QQuickItem *)>(15, 5, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 19 },
        }}),
        // Slot 'pop'
        QtMocHelpers::SlotData<void()>(20, 5, QMC::AccessPublic, QMetaType::Void),
        // Slot 'takeLast'
        QtMocHelpers::SlotData<QQuickItem *()>(21, 5, QMC::AccessPublic, 0x80000000 | 6),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mainUi'
        QtMocHelpers::PropertyData<QQuickItem*>(22, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'columnWidth'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'depth'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
        // property 'currentIndex'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    0 },
    });
    return QtMocHelpers::metaObjectData<KQuickConfigModule, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KQuickConfigModule::staticMetaObject = { {
    QMetaObject::SuperData::link<KAbstractConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KQuickConfigModuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KQuickConfigModuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18KQuickConfigModuleE_t>.metaTypes,
    nullptr
} };

void KQuickConfigModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KQuickConfigModule *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pagePushed((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 1: _t->pageRemoved(); break;
        case 2: _t->columnWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->depthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->mainUiReady(); break;
        case 6: _t->push((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 7: _t->push((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->push((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 9: _t->pop(); break;
        case 10: { QQuickItem* _r = _t->takeLast();
            if (_a[0]) *reinterpret_cast<QQuickItem**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KQuickConfigModule::*)(QQuickItem * )>(_a, &KQuickConfigModule::pagePushed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickConfigModule::*)()>(_a, &KQuickConfigModule::pageRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickConfigModule::*)(int )>(_a, &KQuickConfigModule::columnWidthChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickConfigModule::*)(int )>(_a, &KQuickConfigModule::currentIndexChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickConfigModule::*)(int )>(_a, &KQuickConfigModule::depthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KQuickConfigModule::*)()>(_a, &KQuickConfigModule::mainUiReady, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->mainUi(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->columnWidth(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->depth(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->currentIndex(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setColumnWidth(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setCurrentIndex(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KQuickConfigModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KQuickConfigModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KQuickConfigModuleE_t>.strings))
        return static_cast<void*>(this);
    return KAbstractConfigModule::qt_metacast(_clname);
}

int KQuickConfigModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KAbstractConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KQuickConfigModule::pagePushed(QQuickItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KQuickConfigModule::pageRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KQuickConfigModule::columnWidthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KQuickConfigModule::currentIndexChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KQuickConfigModule::depthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KQuickConfigModule::mainUiReady()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
