/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<kcmlauncher_p.h>)
#  include <kcmlauncher_p.h>
#endif
#if __has_include(<settingstateproxy.h>)
#  include <settingstateproxy.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kcmutils()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<ConfigModuleForeign>("org.kde.kcmutils", 1);
    QMetaType::fromType<KAbstractConfigModule *>().id();
    qmlRegisterEnum<KAbstractConfigModule::Button>("KAbstractConfigModule::Button");
    qmlRegisterEnum<KAbstractConfigModule::Buttons>("KAbstractConfigModule::Buttons");
    qmlRegisterEnum<KAbstractConfigModule::Button>("KAbstractConfigModule::Button");
    qmlRegisterTypesAndRevisions<KCMLauncher>("org.kde.kcmutils", 1);
    qmlRegisterTypesAndRevisions<SettingStateProxy>("org.kde.kcmutils", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kcmutils", 1, 0);
}

static const QQmlModuleRegistration orgkdekcmutilsRegistration("org.kde.kcmutils", qml_register_types_org_kde_kcmutils);
